@@ -10,6 +10,7 @@ from ..helpers.envvar_option import EnvvarOption
 from ..helpers.global_options import GlobalOptions
 from ..helpers.options import resource_option
 from ..helpers.sym_group import SymGroup
+from ..helpers.updater import SymUpdater
 from ..saml_clients.chooser import SAMLClientName, choose_saml_client, option_values
 from ..version import __version__
 
@@ -57,3 +58,5 @@ def sym(
     options.debug = debug
     options.log_dir = log_dir
     options.aws_region = aws_region
+
+    SymUpdater().auto_update()
