@@ -3,8 +3,7 @@ import sys
 from subprocess import CalledProcessError
 from typing import Mapping, Pattern, Type, Union
 
-from click import BadParameter, ClickException, utils
-from click._compat import get_text_stderr
+from click import BadParameter, ClickException
 from sentry_sdk import capture_exception
 
 from .helpers.envvar_option import get_used
