@@ -7,13 +7,14 @@ from sym.cli.helpers.ssh import (
     maybe_gen_ssh_key,
     ssh_key_and_config,
 )
+from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
 from .model import CheckContext, CheckResult, SymCheck, failure, success
 
 
 class GenSshConfigCheck(SymCheck):
     def check(self, ctx: CheckContext) -> CheckResult:
-        client = ctx.options.create_saml_client(ctx.resource)
+        client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
         ssh_config = gen_local_ssh_config(client)
         msg = f"Successfully created local SSH config"
         msg += "\nUsing config: " + str(ssh_config.path)
@@ -23,7 +24,7 @@ class GenSshConfigCheck(SymCheck):
 
 class GenSshKeyCheck(SymCheck):
     def check(self, ctx: CheckContext) -> CheckResult:
-        client = ctx.options.create_saml_client(ctx.resource)
+        client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
         maybe_gen_ssh_key(client)
         ssh_key, _ = ssh_key_and_config(client)
         msg = "Local SSH keys generated"
@@ -41,7 +42,7 @@ class EnsureSshKeyAuthorizedCheck(SymCheck):
 
     def check(self, ctx: CheckContext) -> CheckResult:
         try:
-            client = ctx.options.create_saml_client(ctx.resource)
+            client = SAMLClientFactory.create_saml_client(ctx.resource, ctx.options)
             running_instance = get_ec2_client(client).load_instance_by_alias(
                 self.instance
             )
