@@ -24,78 +24,83 @@ class OrgParams(TypedDict, total=False):
     profiles: Dict[str, Profile]
 
 
-PARAMS: Dict[str, OrgParams] = {
-    "launch-darkly": {
-        "resource_env_var": "ENVIRONMENT",
-        "users": {"ssh": "ubuntu", "ansible": "ansible"},
-        "domain": "launchdarkly.com",
-        "aws_saml_url": (
-            "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272"
-        ),
-        "aws_okta_params": {
-            "mfa_provider": "OKTA",
-            "mfa_factor_type": "push",
-            "assume_role_ttl": "1h",
-            "session_ttl": "30m",
-        },
-        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
-        "profiles": {
-            "production": Profile(
-                display_name="Production",
-                region="us-east-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
-                ansible_bucket="launchdarkly-sym-ansible-production",
-            ),
-            "staging": Profile(
-                display_name="Staging",
-                region="us-east-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
-                ansible_bucket="launchdarkly-sym-ansible-staging",
-            ),
-            "catamorphic": Profile(
-                display_name="Catamorphic",
-                region="us-east-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
-                ansible_bucket="launchdarkly-sym-ansible-catamorphic",
-            ),
-            "prod-intuit": Profile(
-                display_name="Prod: Intuit",
-                region="us-west-2",
-                arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
-                ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
-            ),
-            "staging-intuit": Profile(
-                display_name="Staging: Intuit",
-                region="us-west-2",
-                arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
-                ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
-            ),
-            "production_apac": Profile(
-                display_name="Production: APAC",
-                region="ap-southeast-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
-                ansible_bucket="launchdarkly-sym-ansible-production",
-            ),
-            "production_euw1": Profile(
-                display_name="Production: EU West 1",
-                region="eu-west-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
-                ansible_bucket="launchdarkly-sym-ansible-production",
-            ),
-            "staging_apac": Profile(
-                display_name="Staging: APAC",
-                region="ap-southeast-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
-                ansible_bucket="launchdarkly-sym-ansible-staging",
-            ),
-            "staging_euw1": Profile(
-                display_name="Staging: EU West 1",
-                region="eu-west-1",
-                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
-                ansible_bucket="launchdarkly-sym-ansible-staging",
-            ),
-        },
+# For legacy reasons, we need to maintain multiple org slugs for LD.
+# This allows us to put the config in one place.
+LaunchDarklyParams: OrgParams = {
+    "resource_env_var": "ENVIRONMENT",
+    "users": {"ssh": "ubuntu", "ansible": "ansible"},
+    "domain": "launchdarkly.com",
+    "aws_saml_url": (
+        "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272"
+    ),
+    "aws_okta_params": {
+        "mfa_provider": "OKTA",
+        "mfa_factor_type": "push",
+        "assume_role_ttl": "1h",
+        "session_ttl": "30m",
     },
+    "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
+    "profiles": {
+        "production": Profile(
+            display_name="Production",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+            ansible_bucket="launchdarkly-sym-ansible-production",
+        ),
+        "staging": Profile(
+            display_name="Staging",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+            ansible_bucket="launchdarkly-sym-ansible-staging",
+        ),
+        "catamorphic": Profile(
+            display_name="Catamorphic",
+            region="us-east-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
+            ansible_bucket="launchdarkly-sym-ansible-catamorphic",
+        ),
+        "prod-intuit": Profile(
+            display_name="Prod: Intuit",
+            region="us-west-2",
+            arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
+            ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
+        ),
+        "staging-intuit": Profile(
+            display_name="Staging: Intuit",
+            region="us-west-2",
+            arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
+            ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
+        ),
+        "production_apac": Profile(
+            display_name="Production: APAC",
+            region="ap-southeast-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+            ansible_bucket="launchdarkly-sym-ansible-production",
+        ),
+        "production_euw1": Profile(
+            display_name="Production: EU West 1",
+            region="eu-west-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+            ansible_bucket="launchdarkly-sym-ansible-production",
+        ),
+        "staging_apac": Profile(
+            display_name="Staging: APAC",
+            region="ap-southeast-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+            ansible_bucket="launchdarkly-sym-ansible-staging",
+        ),
+        "staging_euw1": Profile(
+            display_name="Staging: EU West 1",
+            region="eu-west-1",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+            ansible_bucket="launchdarkly-sym-ansible-staging",
+        ),
+    },
+}
+
+PARAMS: Dict[str, OrgParams] = {
+    "launch-darkly": LaunchDarklyParams,
+    "launchdarkly": LaunchDarklyParams,
     "sym": {
         "resource_env_var": "ENVIRONMENT",
         "users": {"ssh": "ubuntu", "ansible": "ubuntu"},
