@@ -18,6 +18,7 @@ from .os import has_command, reset_fds
 
 REQ_TIMEOUT = 1
 INSTALL_TIMEOUT = 30
+SYM_CLI = "sym-cli"
 
 
 class SymUpdater:
@@ -25,6 +26,7 @@ class SymUpdater:
         self.dir = Path(__file__).resolve().parent.parent.parent.parent
         self.latest_version: Optional[VersionInfo] = None
         self.url: Optional[dict] = None
+        self.cli = SYM_CLI
 
     def _log(self, s, **kwargs):
         click.secho(s, err=True, **kwargs)
@@ -38,19 +40,53 @@ class SymUpdater:
     def get_latest_version(self) -> Optional[VersionInfo]:
         try:
             resp = requests.get(
-                "https://pypi.org/pypi/sym-cli/json",
+                f"https://pypi.org/pypi/{self.cli}/json",
                 timeout=REQ_TIMEOUT,
             ).json()
-            version = VersionInfo.parse(resp["info"]["version"])
+        except requests.exceptions.RequestException:
+            return None
 
-            self.latest_version = version
+        new_version = self.get_current_version()
+        for v in resp.get("releases", {}).keys():
+            try:
+                version = VersionInfo.parse(v)
+            except ValueError:
+                continue
+            if (
+                version > new_version
+                and version.major == new_version.major
+                and version.minor == new_version.minor
+            ):
+                new_version = version
+        self.latest_version = new_version
+
+        try:
+            resp2 = requests.get(
+                f"https://pypi.org/pypi/{self.cli}/{new_version}/json",
+                timeout=REQ_TIMEOUT,
+            ).json()
+        except requests.exceptions.RequestException:
+            return None
+
+        try:
             self.url = next(
-                (u for u in resp["urls"] if u["python_version"] == "source"),
+                (u for u in resp2["urls"] if u["python_version"] == "source"),
                 None,
             )
-            return version
-        except (requests.exceptions.RequestException, ValueError, KeyError):
-            return None
+
+            version = VersionInfo.parse(resp["info"]["version"])
+            if version > new_version:
+                self._log(
+                    (
+                        "A major update is available! "
+                        f"Please install it using the install script at https://docs.symops.com/docs/install-{self.cli}."
+                    ),
+                    fg="white",
+                )
+        except (ValueError, KeyError):
+            pass
+
+        return new_version
 
     def needs_update(self) -> bool:
         if (version := self.get_latest_version()) :
@@ -64,7 +100,10 @@ class SymUpdater:
         return (Path.home() / ".local" / "pipx") in self.dir.parents
 
     def is_brew(self):
-        return Path("/usr/local/Cellar") in self.dir.parents
+        return "Cellar" in self.dir.parts
+
+    def is_sitepackage(self):
+        return self.dir.name == "site-packages"
 
     def _update_with_command(
         self, command: Sequence[str], **kwargs
@@ -80,17 +119,23 @@ class SymUpdater:
         except (CalledProcessError, TimeoutExpired):
             return None
 
+    def _update_with_checked_command(self, command: Sequence[str]):
+        return bool(self._update_with_command(command, check=True, capture_output=True))
+
     def update_pipx(self) -> bool:
-        if (cp := self._update_with_command(["pipx", "upgrade", "sym-cli", "--force"])) :
+        if (cp := self._update_with_command(["pipx", "upgrade", self.cli, "--force"])) :
             return cp.returncode in {0, 1}
         return False
 
     def update_brew(self) -> bool:
-        return bool(
-            self._update_with_command(
-                ["brew", "upgrade", "sym-cli"], check=True, capture_output=True
-            )
-        )
+        return self._update_with_checked_command(["brew", "upgrade", self.cli])
+
+    def update_sitepackage(self) -> bool:
+        pip = self.dir.parent.parent.parent / "bin" / "pip"
+        if not pip.exists():
+            self._log("pip must be installed", fg="red")
+            return False
+        return self._update_with_checked_command([str(pip), "install", "-U", self.cli])
 
     def update_other(self) -> bool:
         if not self.url:
@@ -103,7 +148,7 @@ class SymUpdater:
             return False
 
         try:
-            prefix = f"sym-cli-{self.latest_version}/"
+            prefix = f"{self.cli}-{self.latest_version}/"
             with tarfile.open(filename) as tar:
                 for member in tar.getmembers():
                     if not member.name.startswith(prefix):
@@ -119,6 +164,8 @@ class SymUpdater:
             return self.update_pipx()
         if self.is_brew():
             return self.update_brew()
+        if self.is_sitepackage():
+            return self.update_sitepackage()
         return self.update_other()
 
     def update(self, replace=False):
