@@ -273,3 +273,10 @@ class SAMLClient(ABC):
             key: overrides.get(key, getattr(self, key)) for key in ["resource", "options"]
         }
         return (klass or self.__class__)(**kwargs)
+
+    def send_analytics_event(self):
+        segment.track(
+            "Resource Requested",
+            global_options=self.options,
+            resource=self.resource,
+        )
