@@ -1,5 +1,6 @@
 import datetime
 import os
+import re
 from pathlib import Path
 from unittest.mock import MagicMock
 
@@ -13,6 +14,10 @@ def test_pipx_path(pipx_updater):
     assert pipx_updater.is_pipx() == True
 
 
+def test_sitepackage_path(sitepackage_updater):
+    assert sitepackage_updater.is_sitepackage() == True
+
+
 def test_brew_path(brew_updater):
     assert brew_updater.is_brew() == True
 
@@ -56,6 +61,8 @@ def test_check_after_a_day(pipx_updater, time_travel):
 
 def test_get_version(updater):
     assert updater.get_latest_version() is not None
+    assert updater.get_latest_version().major == 0
+    assert updater.get_latest_version().minor == 0
 
 
 def test_needs_update(pipx_updater):
@@ -74,6 +81,18 @@ def test_failed_fetch(pipx_updater):
     assert pipx_updater.needs_update() is False
 
 
+def test_update_sitepackage(sitepackage_updater, capture_command):
+    with capture_command():
+        assert sitepackage_updater._update() == True
+    capture_command.assert_command(re.compile(r"pip install -U sym-cli"))
+
+
+def test_update_sitepackage_failed(sitepackage_updater, capture_command):
+    capture_command.register_output("pip", "", exit_code=1)
+    with capture_command():
+        assert sitepackage_updater._update() == False
+
+
 def test_update_pipx(pipx_updater, capture_command):
     with capture_command():
         assert pipx_updater._update() == True
