@@ -2,7 +2,6 @@ import random
 from contextlib import contextmanager
 
 import pytest
-from click.testing import CliRunner
 from expects import *
 
 from sym.cli.sym import sym as click_command
@@ -23,10 +22,10 @@ INSTANCES = [
 
 
 @pytest.fixture
-def integration_runner(capfdbinary, sandbox):
+def integration_runner(capfdbinary, sandbox, wrapped_cli_runner):
     @contextmanager
     def context():
-        runner = CliRunner()
+        runner = wrapped_cli_runner
         with sandbox.push_xdg_config_home():
 
             def run(*args):
